==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/weather_status/l10n/gl.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Enderezo descoñecido",
    "No result." : "Sen resultados.",
    "Malformed JSON data." : "Datos JSON con formato incorrecto.",
    "Error" : "Erro",
    "Weather status" : "Estado meteorolóxico",
    "Weather status in your dashboard" : "Estado meteorolóxico no seu panel",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estado meteorolóxico integrado na aplicación do Taboleiro.\n    A localización do usuario pódese determinar automaticamente ou definir manualmente. A seguir amósase unha previsión de 6 horas.\n    Este estado tamén se pode integrar noutros lugares como a aplicación Calendario.",
    "Detect location" : "Detectar localización",
    "Set custom address" : "Estabelecer o enderezo personalizado",
    "Favorites" : "Favoritos",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit}, ceo despexado ás {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit}, nubrado ás {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit}, día claro ás {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit}, noite clara ás {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit}, parcialmente nubrado ás {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit}, brétema ás {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit}, poalla ás {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit}, chuvia ás {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperatura} {unidade} arroiada ás {hora}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit}, balloada ás {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit}, balloadas escasas ás {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperatura} {unidade} balloadas intensas ás {hora}",
    "More weather for {adr}" : "Máis previsións para {adr}",
    "Loading weather" : "Cargando as previsións",
    "Set location for weather" : "Estabelecer a localización para as previsións meteorolóxicas",
    "Remove from favorites" : "Retirar de favoritos",
    "Add as favorite" : "Engadir como favorito",
    "You are not logged in." : "Aínda non accedeu.",
    "There was an error getting the weather status information." : "Produciuse un erro ao obter a información do estado do tempo.",
    "No weather information found" : "Non se atopou información meteorolóxica",
    "Location not found" : "Non se atopou a localización",
    "There was an error setting the location address." : "Produciuse un erro ao axustar o enderezo da localización.",
    "There was an error setting the location." : "Produciuse un erro ao axustar a localización",
    "There was an error saving the mode." : "Produciuse un erro ao gardar o modo.",
    "There was an error using personal address." : "Produciuse un erro ao usar o enderezo persoal.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estado meteorolóxico integrado na aplicación do Taboleiro.\n    A localización do usuario pódese determinar automaticamente ou definir manualmente. A seguir amósase unha previsión de 6 horas.\n    Este estado tamén se pode integrar noutros lugares como a aplicación Calendario."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/weather_status/l10n/gl.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Enderezo descoñecido",
    "No result." : "Sen resultados.",
    "Malformed JSON data." : "Datos JSON con formato incorrecto.",
    "Error" : "Erro",
    "Weather status" : "Estado meteorolóxico",
    "Weather status in your dashboard" : "Estado meteorolóxico no seu taboleiro",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estado meteorolóxico integrado na aplicación do Taboleiro.\n    A localización do usuario pódese determinar automaticamente ou definir manualmente. A seguir amósase unha previsión de 6 horas.\n    Este estado tamén se pode integrar noutros lugares como a aplicación Calendario.",
    "Detect location" : "Detectar localización",
    "Set custom address" : "Estabelecer o enderezo personalizado",
    "Favorites" : "Favoritos",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit}, ceo despexado ás {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit}, nubrado ás {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit}, día claro ás {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit}, noite clara ás {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit}, parcialmente nubrado ás {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit}, brétema ás {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit}, poalla ás {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit}, chuvia ás {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperatura} {unidade} arroiada ás {hora}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit}, balloada ás {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit}, balloadas escasas ás {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperatura} {unidade} balloadas intensas ás {hora}",
    "More weather for {adr}" : "Máis previsións para {adr}",
    "Loading weather" : "Cargando as previsións",
    "Set location for weather" : "Estabelecer a localización para as previsións meteorolóxicas",
    "Remove from favorites" : "Retirar de favoritos",
    "Add as favorite" : "Engadir como favorito",
    "You are not logged in." : "Aínda non accedeu.",
    "There was an error getting the weather status information." : "Produciuse un erro ao obter a información do estado do tempo.",
    "No weather information found" : "Non se atopou información meteorolóxica",
    "Location not found" : "Non se atopou a localización",
    "There was an error setting the location address." : "Produciuse un erro ao axustar o enderezo da localización.",
    "There was an error setting the location." : "Produciuse un erro ao axustar a localización",
    "There was an error saving the mode." : "Produciuse un erro ao gardar o modo.",
    "There was an error using personal address." : "Produciuse un erro ao usar o enderezo persoal.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estado meteorolóxico integrado na aplicación do Taboleiro.\n    A localización do usuario pódese determinar automaticamente ou definir manualmente. A seguir amósase unha previsión de 6 horas.\n    Este estado tamén se pode integrar noutros lugares como a aplicación Calendario."
},
"nplurals=2; plural=(n != 1);");
